diff src/plugins/plugin_exp_command_export.py @ 2144:1d3f73e065e1

core, jp: component handling + client handling refactoring: - SàT can now handle components - plugin have now a "modes" key in PLUGIN_INFO where they declare if they can be used with clients and or components. They default to be client only. - components are really similar to clients, but with some changes in behaviour: * component has "entry point", which is a special plugin with a componentStart method, which is called just after component is connected * trigger end with a different suffixes (e.g. profileConnected vs profileConnectedComponent), so a plugin which manage both clients and components can have different workflow * for clients, only triggers of plugins handling client mode are launched * for components, only triggers of plugins needed in dependencies are launched. They all must handle component mode. * component have a sendHistory attribute (False by default) which can be set to True to allow saving sent messages into history * for convenience, "client" is still used in method even if it can now be a component * a new "component" boolean attribute tells if we have a component or a client * components have to add themselve Message protocol * roster and presence protocols are not added for components * component default port is 5347 (which is Prosody's default port) - asyncCreateProfile has been renamed for profileCreate, both to follow new naming convention and to prepare the transition to fully asynchronous bridge - createProfile has a new "component" attribute. When used to create a component, it must be set to a component entry point - jp: added --component argument to profile/create - disconnect bridge method is now asynchronous, this way frontends can know when disconnection is finished - new PI_* constants for PLUGIN_INFO values (not used everywhere yet) - client/component connection workflow has been moved to their classes instead of being a host methods - host.messageSend is now client.sendMessage, and former client.sendMessage is now client.sendMessageData. - identities are now handled in client.identities list, so it can be updated dynamically by plugins (in the future, frontends should be able to update them too through bridge) - profileConnecting* profileConnected* profileDisconnected* and getHandler now all use client instead of profile
author Goffi <goffi@goffi.org>
date Sun, 12 Feb 2017 17:55:43 +0100
parents a2bc5089c2eb
children 33c8c4973743
line wrap: on
line diff
--- a/src/plugins/plugin_exp_command_export.py	Tue Feb 07 00:15:03 2017 +0100
+++ b/src/plugins/plugin_exp_command_export.py	Sun Feb 12 17:55:43 2017 +0100
@@ -41,11 +41,11 @@
 class ExportCommandProtocol(protocol.ProcessProtocol):
     """ Try to register an account with prosody """
 
-    def __init__(self, parent, target, options, profile):
+    def __init__(self, parent, client, target, options):
         self.parent = parent
         self.target = target
         self.options = options
-        self.profile = profile
+        self.client = client
 
     def _clean(self, data):
         if not data:
@@ -58,10 +58,10 @@
         log.info("connectionMade :)")
 
     def outReceived(self, data):
-        self.parent.host.messageSend(self.target, {'': self._clean(data)}, no_trigger=True, profile_key=self.profile)
+        self.client.sendMessage(self.target, {'': self._clean(data)}, no_trigger=True)
 
     def errReceived(self, data):
-        self.parent.host.messageSend(self.target, {'': self._clean(data)}, no_trigger=True, profile_key=self.profile)
+        self.client.sendMessage(self.target, {'': self._clean(data)}, no_trigger=True)
 
     def processEnded(self, reason):
         log.info (u"process finished: %d" % (reason.value.exitCode,))
@@ -81,8 +81,9 @@
 
 class CommandExport(object):
     """Command export plugin: export a command to an entity"""
     #XXX: This plugin can be potentially dangerous if we don't trust entities linked
     #     this is specially true if we have other triggers.
 
     def __init__(self, host):
         log.info(_("Plugin command export initialization"))
@@ -96,10 +97,10 @@
         @param entity: jid.JID attached to the process
         @param process: process to remove"""
         try:
-            processes_set = self.spawned[(entity, process.profile)]
+            processes_set = self.spawned[(entity, process.client.profile)]
             processes_set.discard(process)
             if not processes_set:
-                del(self.spawned[(entity, process.profile)])
+                del(self.spawned[(entity, process.client.profile)])
         except ValueError:
             pass
 
@@ -140,11 +141,7 @@
                         - pty: if set, launch in a pseudo terminal
                         - continue: continue normal MessageReceived handling
         """
-        profile = self.host.memory.getProfileName(profile_key)
-        if not profile:
-            log.warning(u"Unknown profile [%s]" % (profile,))
-            return
-
+        client = self.host.getClient(profile_key)
         for target in targets:
             try:
                 _jid = jid.JID(target)
@@ -154,7 +151,7 @@
             except (RuntimeError, jid.InvalidFormat, AttributeError):
                 log.info(u"invalid target ignored: %s" % (target,))
                 continue
-            process_prot = ExportCommandProtocol(self, _jid, options, profile)
-            self.spawned.setdefault((_jid, profile),set()).add(process_prot)
+            process_prot = ExportCommandProtocol(self, client, _jid, options)
+            self.spawned.setdefault((_jid, client.profile),set()).add(process_prot)
             reactor.spawnProcess(process_prot, command, args, usePTY = process_prot.boolOption('pty'))
@@ -81,8 +81,9 @@
 class CommandExport(object):
     """Command export plugin: export a command to an entity"""
-    #XXX: This plugin can be potentially dangerous if we don't trust entities linked
-    #     this is specially true if we have other triggers.
+    # XXX: This plugin can be potentially dangerous if we don't trust entities linked
+    #      this is specially true if we have other triggers.
+    # FIXME: spawned should be a client attribute, not a class one
 
     def __init__(self, host):